@@ -1,5 +1,5 @@
-CREATE FUNCTION check_control_type(p_parent_schema text, p_parent_tablename text, p_control text) RETURNS TABLE (general_type text, exact_type text) 
-    LANGUAGE sql STABLE SECURITY DEFINER
+CREATE FUNCTION @extschema@.check_control_type(p_parent_schema text, p_parent_tablename text, p_control text) RETURNS TABLE (general_type text, exact_type text) 
+    LANGUAGE sql STABLE
 AS $$
 /* 
  * Return column type for given table & column in that table
@@ -22,3 +22,4 @@ SELECT CASE
     AND a.attname = p_control::name
 $$;
 
+
