@@ -32,6 +32,7 @@ v_datetime_string               text;
 v_default_partition             text;
 v_higher_control_type           text;
 v_higher_parent_control         text;
+v_higher_parent_epoch           text;
 v_higher_parent_schema          text := split_part(p_parent_table, '.', 1);
 v_higher_parent_table           text := split_part(p_parent_table, '.', 2);
 v_id_interval                   bigint;
@@ -562,8 +563,8 @@ IF v_control_type = 'id' AND p_epoch = 'none' THEN
             JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
             WHERE n.nspname = v_higher_parent_schema::name
             AND c.relname = v_higher_parent_table::name
-        ) SELECT n.nspname, c.relname, p.control
-        INTO v_higher_parent_schema, v_higher_parent_table, v_higher_parent_control
+        ) SELECT n.nspname, c.relname, p.control, p.epoch
+        INTO v_higher_parent_schema, v_higher_parent_table, v_higher_parent_control, v_higher_parent_epoch
         FROM pg_catalog.pg_class c
         JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
         JOIN top_oid t ON c.oid = t.top_parent_oid
@@ -572,7 +573,7 @@ IF v_control_type = 'id' AND p_epoch = 'none' THEN
         IF v_higher_parent_table IS NOT NULL THEN
             SELECT general_type INTO v_higher_control_type
             FROM @extschema@.check_control_type(v_higher_parent_schema, v_higher_parent_table, v_higher_parent_control);
-            IF v_higher_control_type <> 'id' THEN
+            IF v_higher_control_type <> 'id' or (v_higher_control_type = 'id' AND v_higher_parent_epoch <> 'none') THEN
                 -- The parent above the p_parent_table parameter is not partitioned by ID
                 --   so don't check for max values in parents that aren't partitioned by ID.
                 -- This avoids missing child tables in subpartition sets that have differing ID data
